@@ -20,7 +20,7 @@
 #define EFFECT_H
 
 class QString;
-class QGraphicsItem;
+class GraphicsElement;
 
 class Effect
 {
@@ -34,7 +34,7 @@ public:
     Effect();
     static Effect* getEffect(QString const& name);
     virtual bool setAttribute(QString const& name, QString const& value) = 0;
-    virtual void apply(QGraphicsItem* item) = 0;
+    virtual void apply(GraphicsElement* item) = 0;
 
 protected:
     int getAttribute(QString const& name, QString const& value, const AttributeDetails details[], int count, qreal& realValue);
