@@ -25,6 +25,8 @@ class QVBoxLayout;
 class QHBoxLayout;
 class ThemeSelector;
 class UnitSelector;
+class PoiSettings;
+class SpeedAlarmSettings;
 
 class MainMenu : public QDialog
 {
@@ -46,6 +48,8 @@ private slots:
     void selectUnit();
     void showAbout();
     void confirmReset();
+    void openPoiAlerts();
+    void openSpeedAlarm();
 
 private:
     QVBoxLayout* layout_;
@@ -53,6 +57,8 @@ private:
     QHBoxLayout* currentRow_;
     ThemeSelector* themeSelector_;
     UnitSelector* unitSelector_;
+    PoiSettings* poiSettings_;
+    SpeedAlarmSettings* speedAlarmSettings_;
     QDialog* aboutDialog_;
 };
 
