@@ -31,13 +31,21 @@
 #include "widgetscreen.h"
 #include "poialerts.h"
 #include "speedalarm.h"
+#include "mediaplayer.h"
+#include "orientation.h"
+#include <QOrientationSensor>
+#include <QSensor>
 
-MainWindow::MainWindow(): QMainWindow(0), menu_(0), themeLoader_(0), mainScreen_(0)
+
+MainWindow::MainWindow(): QMainWindow(0), menu_(0), themeLoader_(0),
+mainScreen_(0), orientation_(0)
 {
     setWindowTitle(tr("jSpeed"));
     showFullScreen();
+    orientation_ = new Orientation(this);
+    orientation_->start();
     addScreens();
-    QTimer::singleShot(800, this, SLOT(loadServices()));
+    QTimer::singleShot(500, this, SLOT(loadServices()));
 }
 
 MainWindow::~MainWindow()
@@ -49,11 +57,13 @@ void MainWindow::loadServices()
 {
     Odometer::instance().start();
     QApplication::processEvents();
+    startBacklight();
+    QApplication::processEvents();
     PoiAlerts::instance().start();
     QApplication::processEvents();
     SpeedAlarm::instance().start();
     QApplication::processEvents();
-    startBacklight();
+    MediaPlayer::init();
 }
 
 void MainWindow::addScreens()
@@ -91,20 +101,20 @@ bool MainWindow::loadTheme()
         return false;
     }
 
-    if(mainScreen_->orientationEnabled(WidgetScreen::LANDSCAPE) &&
-       mainScreen_->orientationEnabled(WidgetScreen::PORTRAIT))
+    int orientations = 0;
+
+    if(mainScreen_->orientationEnabled(WidgetScreen::LANDSCAPE))
     {
-        setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+        orientations |= Orientation::LANDSCAPE;
     }
-    else if(mainScreen_->orientationEnabled(WidgetScreen::PORTRAIT))
+    if(mainScreen_->orientationEnabled(WidgetScreen::PORTRAIT))
     {
-        setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-    }
-    else
-    {
-        setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
+        orientations |= Orientation::PORTRAIT;
     }
 
+    orientation_->setSupportedOrientations(orientations);
+    orientation_->update();
+
     return true;
 }
 
