@@ -25,6 +25,7 @@ class MainWindowStack;
 class MainMenu;
 class ThemeLoader;
 class WidgetScreen;
+class Orientation;
 
 class MainWindow : public QMainWindow
 {
@@ -52,6 +53,7 @@ private:
     MainMenu* menu_;
     ThemeLoader* themeLoader_;
     WidgetScreen* mainScreen_;
+    Orientation* orientation_;
 
 };
 
