@@ -109,7 +109,7 @@ void PoiSettings::loadFiles()
 
     poiFileSelector_->clear();
     QString selectedPoi = Settings::instance().value("alert_poi_file", "").toString();
-    poiFileSelector_->loadFiles(PoiAlerts::getPoiDir(), PoiReader::getFormatPattern());
+    poiFileSelector_->loadFiles(PoiAlerts::getPoiDir(), PoiReader::getFormatPattern(), true);
     poiFileSelector_->selectByValue(selectedPoi);
 
 }
