@@ -28,17 +28,22 @@ class WidgetScreen;
 
 class ThemeLoader : public QObject
 {
+    Q_OBJECT
+
 public:
     ThemeLoader(WidgetScreen* mainScreen, WidgetScreen* detailScreen, QObject* parent = 0);
     ~ThemeLoader();
-    bool load();
     QString const& error() const;
     static QString getThemeDir();
     static QString const& getThemeSuffix();
 
+public slots:
+    bool load();
+
 private:
     bool read();
     bool loadScreen(QString const& tag, QDomDocument const& doc, WidgetScreen* screen);
+    QString theme_;
     Reader* reader_;
     QString error_;
     WidgetScreen* mainScreen_;
