@@ -33,7 +33,8 @@
 #include "settings.h"
 #include "themeschedulersettings.h"
 
-ThemeSelector::ThemeSelector(QWidget* parent): QDialog(parent), themeScheduler_(0)
+ThemeSelector::ThemeSelector(QWidget* parent): QDialog(parent),
+buttonClicked_(false), themeSelected_(false), themeScheduler_(0)
 {
     setWindowTitle(tr("Select theme"));
 
@@ -49,7 +50,8 @@ ThemeSelector::ThemeSelector(QWidget* parent): QDialog(parent), themeScheduler_(
     buttons->addButton(saveButton, QDialogButtonBox::AcceptRole);
 
     selector_ = new ThemePicker(tr("Theme"), this);
-    connect(selector_, SIGNAL(selected()), this, SLOT(disableScheduler()));
+    connect(selector_, SIGNAL(clicked(bool)), this, SLOT(setButtonClicked()));
+    connect(selector_, SIGNAL(selected()), this, SLOT(setThemeSelected()));
 
     QPushButton* loadButton = new QPushButton(tr("Import"));
     connect(loadButton, SIGNAL(clicked(bool)), this, SLOT(loadFromFile()));
@@ -75,6 +77,15 @@ void ThemeSelector::saveTheme()
     QString theme = selector_->value().toString();
     Settings::instance().setValue("theme", theme);
     hide();
+
+    if(buttonClicked_ && themeSelected_ && ThemeScheduler::instance().isEnabled())
+    {
+        QMaemo5InformationBox::information(this, tr("Disabling theme scheduler..."), 1000);
+        ThemeScheduler::instance().setEnabled(false);
+        themeSelected_ = false;
+        buttonClicked_ = false;
+    }
+
     emit themeChanged();
 }
 
@@ -98,17 +109,31 @@ void ThemeSelector::openScheduler()
     if(!themeScheduler_)
     {
         themeScheduler_ = new ThemeSchedulerSettings(this);
-        connect(themeScheduler_, SIGNAL(themeChanged()), this, SIGNAL(themeChanged()));
+        connect(themeScheduler_, SIGNAL(themeChanged()), this, SLOT(onThemeChanged()));
     }
 
     themeScheduler_->show();
 }
 
-void ThemeSelector::disableScheduler()
+void ThemeSelector::setButtonClicked()
 {
-    if(ThemeScheduler::instance().isEnabled())
-    {
-        QMaemo5InformationBox::information(this, tr("Disabling theme scheduler..."), 1000);
-        ThemeScheduler::instance().setEnabled(false);
-    }
+    buttonClicked_ = true;
+}
+
+void ThemeSelector::setThemeSelected()
+{
+    themeSelected_ = true;
+}
+
+void ThemeSelector::onThemeChanged()
+{
+    buttonClicked_ = false;
+    themeSelected_ = false;
+    emit themeChanged();
+}
+
+
+void ThemeSelector::setVisible(bool visible)
+{
+    QDialog::setVisible(visible);
 }
