@@ -35,13 +35,20 @@ public:
 signals:
     void themeChanged();
 
+protected:
+    virtual void setVisible(bool visible);
+
 private slots:
     void saveTheme();
     void loadFromFile();
     void openScheduler();
-    void disableScheduler();
+    void setButtonClicked();
+    void setThemeSelected();
+    void onThemeChanged();
 
 private:
+    bool buttonClicked_;
+    bool themeSelected_;
     ThemePicker* selector_;
     ThemeSchedulerSettings* themeScheduler_;
 };
